powered by
Static - Kibior is instance
an object
TRUE if the given object is an instance of Kibior, else FALSE
Tests if a given object is a Kibior instance. Basically compute symmetric difference between two sets of class.
Other comparison: Kibior equals operator, Kibior not-equals operator
Kibior equals operator
Kibior not-equals operator